@@ -365,6 +365,10 @@ TestDraft201909 = DRAFT201909.to_unittest_testcase(
             subject="anchor",
             case_description="same $anchor with different base uri",
         )(test)
+        or skip(
+            message="Vocabulary support is not yet present.",
+            subject="vocabulary",
+        )(test)
         or skip(
             message=bug(),
             subject="ref",
@@ -413,6 +417,10 @@ TestDraft202012 = DRAFT202012.to_unittest_testcase(
             subject="anchor",
             case_description="same $anchor with different base uri",
         )(test)
+        or skip(
+            message="Vocabulary support is not yet present.",
+            subject="vocabulary",
+        )(test)
         or skip(
             message=bug(),
             subject="ref",
